==> matmflutterplugin-0.0.5.tar.gz: lib/Battery.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:matmflutterplugin/matmflutterplugin.dart';
import 'package:android_intent/android_intent.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_appavailability/flutter_appavailability.dart';
import 'package:intent/extra.dart';
import 'package:store_redirect/store_redirect.dart';
import 'package:intent/intent.dart' as android_intent;
import 'package:intent/extra.dart' as android_extra;
import 'package:intent/typedExtra.dart' as android_typedExtra;
import 'package:intent/action.dart' as android_action;
class Battery {
  BuildContext buildContext;
  Battery(this.buildContext);

  Future<void> loadMATMSDK() {
    try {
      final AndroidIntent intent = const AndroidIntent(
        package: "com.microatm.services",
        componentName: 'com.microatm.services.Activities.MainActivity',
        action: 'action_view',
        arguments: <String, dynamic>{
          'mobileNo': '9821020369',
          'agent_id': '2190',
          'developer_id': "BANKIT",
          'password': "BANKIT",
          'partnerAgentId': '',
          'clientTransactionId': "1212212121212",
        },
      );
      intent.launch();
    } catch (e) {
      showAppNotAvailableDialog(buildContext, "Please download mATM Service");
    }
  }
  showAppNotAvailableDialog(BuildContext context, String message) {
    // set up the buttons

    Widget launchButton = FlatButton(
      child: Text("Download  Service"),
      onPressed: () {
        StoreRedirect.redirect(
            androidAppId: "com.microatm.services", iOSAppId: "");
        Navigator.pop(context);
      },
    );

    Widget closeButton = FlatButton(
      child: Text("Cancel"),
      onPressed: () {
        Navigator.pop(context);
      },
    );
    // set up the AlertDialog
    AlertDialog alert = AlertDialog(
      content: Text(message),
      actions: [launchButton, closeButton],
    );

    // show the dialog
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return alert;
      },
    );
  }
}

==> matmflutterplugin-0.0.6.tar.gz: lib/Battery.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:matmflutterplugin/matmflutterplugin.dart';
import 'package:android_intent/android_intent.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_appavailability/flutter_appavailability.dart';
import 'package:intent/extra.dart';
import 'package:store_redirect/store_redirect.dart';
import 'package:intent/intent.dart' as android_intent;
import 'package:intent/extra.dart' as android_extra;
import 'package:intent/typedExtra.dart' as android_typedExtra;
import 'package:intent/action.dart' as android_action;
class MATMProvider {
  BuildContext buildContext;
  MATMProvider(this.buildContext);

  Future<void> loadMATM() {
    try {
      final AndroidIntent intent = const AndroidIntent(
        package: "com.microatm.services",
        componentName: 'com.microatm.services.Activities.MainActivity',
        action: 'action_view',
        arguments: <String, dynamic>{
          'mobileNo': '9821020369',
          'agent_id': '2190',
          'developer_id': "BANKIT",
          'password': "BANKIT",
          'partnerAgentId': '',
          'clientTransactionId': "1212212121212",
        },
      );
      intent.launch();
    } catch (e) {
      showAppNotAvailableDialog(buildContext, "Please download mATM Service");
    }
  }
  showAppNotAvailableDialog(BuildContext context, String message) {
    // set up the buttons

    Widget launchButton = FlatButton(
      child: Text("Download  Service"),
      onPressed: () {
        StoreRedirect.redirect(
            androidAppId: "com.microatm.services", iOSAppId: "");
        Navigator.pop(context);
      },
    );

    Widget closeButton = FlatButton(
      child: Text("Cancel"),
      onPressed: () {
        Navigator.pop(context);
      },
    );
    // set up the AlertDialog
    AlertDialog alert = AlertDialog(
      content: Text(message),
      actions: [launchButton, closeButton],
    );

    // show the dialog
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return alert;
      },
    );
  }
}
